(spec-aware-namespace-keyword spec unqualified-kw)(spec-aware-namespace-map spec-keyword unnamespaced-map)Convert unnamespaced map to properly namespaced map based on spec registry. Looks up where each spec is actually defined and uses that namespace.
Convert unnamespaced map to properly namespaced map based on spec registry. Looks up where each spec is actually defined and uses that namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |