bioscoop.ffmpeg


ffmpeg-binclj


ffplay-binclj


ffprobe-binclj


filter-complexclj

(filter-complex filter
                &
                {:keys [working-dir output]
                 :or {working-dir (System/getProperty "java.io.tmpdir")
                      output "output.mp4"}})

with-inputsclj

(with-inputs filtergraph inputs)
(with-inputs filtergraph out & inputs)

It's possible to destroy the process if we keep a handle on the Process instance

It's possible to destroy the process if we keep a handle on the Process instance
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries