bioscoop.render


drop-namespace-from-mapclj

(drop-namespace-from-map m)

Transforms a map by removing the namespace from qualified keyword keys.

Transforms a map by removing the namespace from qualified keyword keys.
raw docstring

Renderablecljprotocol

to-dslclj

(to-dsl this)

Convert to DSL string

Convert to DSL string

to-ffmpegclj

(to-ffmpeg this)

Convert to ffmpeg filter string

Convert to ffmpeg filter string

cljdoc builds & hosts documentation for Clojure/Script libraries