(filter-complex filter
&
{:keys [working-dir output]
:or {working-dir (System/getProperty "java.io.tmpdir")
output "output.mp4"}})(with-inputs filtergraph inputs)(with-inputs filtergraph out & inputs)It's possible to destroy the process if we keep a handle on the Process instance
It's possible to destroy the process if we keep a handle on the Process instance
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |